VERSION = "0.15"
URL = "https://github.com/oskar456/poledni-menu"
TAGLINE = (
    "Vygenerováno nástrojem [poledni-menu]({URL}) verze {VERSION}. "
    "Pull requesty jsou vítány."
).format(URL=URL, VERSION=VERSION)
